@@ -2,38 +2,38 @@ from palp.network.request import Request
 
 
 class RequestGet(Request):
-    def __init__(self, **kwargs):
-        kwargs.update({'method': 'GET'})
+    def __init__(self, url, **kwargs):
+        kwargs.update({'url': url, 'method': 'GET'})
         super().__init__(**kwargs)
 
 
 class RequestPost(Request):
-    def __init__(self, **kwargs):
-        kwargs.update({'method': 'POST'})
+    def __init__(self, url, **kwargs):
+        kwargs.update({'url': url, 'method': 'POST'})
         super().__init__(**kwargs)
 
 
 class RequestOptions(Request):
-    def __init__(self, **kwargs):
-        kwargs.update({'method': 'OPTIONS'})
+    def __init__(self, url, **kwargs):
+        kwargs.update({'url': url, 'method': 'OPTIONS'})
         super().__init__(**kwargs)
 
 
 class RequestHead(Request):
-    def __init__(self, **kwargs):
-        kwargs.update({'method': 'HEAD'})
+    def __init__(self, url, **kwargs):
+        kwargs.update({'url': url, 'method': 'HEAD'})
         super().__init__(**kwargs)
 
 
 class RequestPatch(Request):
-    def __init__(self, **kwargs):
-        kwargs.update({'method': 'PATCH'})
+    def __init__(self, url, **kwargs):
+        kwargs.update({'url': url, 'method': 'PATCH'})
         super().__init__(**kwargs)
 
 
 class RequestDelete(Request):
-    def __init__(self, **kwargs):
-        kwargs.update({'method': 'DELETE'})
+    def __init__(self, url, **kwargs):
+        kwargs.update({'url': url, 'method': 'DELETE'})
         super().__init__(**kwargs)
 
 
